p2play-commit Mailing List for P2Play
Status: Pre-Alpha
Brought to you by:
tisoft
You can subscribe to this list here.
| 2006 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
|
Oct
|
Nov
|
Dec
(17) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2007 |
Jan
(17) |
Feb
|
Mar
(18) |
Apr
|
May
|
Jun
(1) |
Jul
(8) |
Aug
(20) |
Sep
|
Oct
|
Nov
|
Dec
|
|
From: <ti...@us...> - 2007-08-22 08:26:46
|
Revision: 81
http://p2play.svn.sourceforge.net/p2play/?rev=81&view=rev
Author: tisoft
Date: 2007-08-22 01:26:32 -0700 (Wed, 22 Aug 2007)
Log Message:
-----------
updated pom
Modified Paths:
--------------
trunk/parent/pom.xml
Added Paths:
-----------
trunk/parent/src/
trunk/parent/src/site/
trunk/parent/src/site/site.xml
Modified: trunk/parent/pom.xml
===================================================================
--- trunk/parent/pom.xml 2007-08-22 06:58:12 UTC (rev 80)
+++ trunk/parent/pom.xml 2007-08-22 08:26:32 UTC (rev 81)
@@ -44,7 +44,7 @@
<developerConnection>
scm:svn:https://p2play.svn.sourceforge.net/svnroot/p2play/trunk/parent/
</developerConnection>
- <url>http://p2play.svn.sourceforge.net/viewvc/p2play/</url>
+ <url>http://p2play.svn.sourceforge.net/viewvc/p2play/trunk/parent/</url>
</scm>
<mailingLists>
@@ -56,7 +56,6 @@
<unsubscribe>
https://lists.sourceforge.net/lists/listinfo/p2play-commit
</unsubscribe>
- <post>p2p...@li...</post>
<archive>
http://sourceforge.net/mailarchive/forum.php?forum_name=p2play-commit
</archive>
@@ -244,6 +243,11 @@
<plugin>
<groupId>org.codehaus.mojo</groupId>
<artifactId>changelog-maven-plugin</artifactId>
+ <configuration>
+ <displayFileDetailUrl>
+ http://p2play.svn.sourceforge.net/viewvc/p2play/%FILE%?view=markup
+ </displayFileDetailUrl>
+ </configuration>
</plugin>
<plugin>
<groupId>org.codehaus.mojo</groupId>
Added: trunk/parent/src/site/site.xml
===================================================================
--- trunk/parent/src/site/site.xml (rev 0)
+++ trunk/parent/src/site/site.xml 2007-08-22 08:26:32 UTC (rev 81)
@@ -0,0 +1,76 @@
+<?xml version="1.0" encoding="ISO-8859-1"?>
+<project name="P2Play">
+
+ <publishDate position="left" format="MM-dd-yyyy HH:mm z 'GMT'Z" />
+
+<!-- <bannerLeft>
+ <name>J2ME Device Emulator</name>
+ <src>http://www.microemu.org/images/logo.png</src>
+ <href>http://www.microemu.org/</href>
+ </bannerLeft>-->
+
+ <bannerRight>
+ <name>Sourceforge</name>
+ <src>http://sourceforge.net/sflogo.php?group_id=183713&amp;type=4</src>
+ <href>http://sourceforge.net/projects/p2play/</href>
+ </bannerRight>
+
+ <poweredBy>
+ <logo
+ name="Hosted on SF.net"
+ href="http://sourceforge.net/projects/microemulator/"
+ img="http://sourceforge.net/sflogo.php?group_id=183713&amp;type=1"/>
+ <logo
+ name="Built by Maven"
+ href="http://maven.apache.org"
+ img="images/logos/maven-feather.png"/>
+<!-- <logo
+ name="Metrics"
+ href="http://www.ohloh.net/projects/6490"
+ img="http://www.ohloh.net/projects/6490/badge.gif" />-->
+ </poweredBy>
+
+ <body>
+ <!-- <links>
+ <item name="Live examples" href="http://www.microemu.org/demo.html"/>
+ </links>-->
+
+ <menu ref="parent" />
+
+ <menu name="Overview">
+<!-- <item name="Introduction" href="http://www.microemu.org/index.html" />
+ <item name="Usage" href="http://www.microemu.org/usage.html" />
+ <item name="Applet config" href="http://www.microemu.org/applet.html" />
+ <item name="Skin" href="http://www.microemu.org/skin.html" />
+ <item name="Unit Tests" href="http://www.microemu.org/unittests.html" />
+ <item name="Faq" href="http://www.microemu.org/faq.html" />-->
+
+ <item name="Download" href="#">
+ <!--4snapshot-->
+<!-- <item name="Snapshot" href="http://www.microemu.org/microemulator/download/"/>
+
+ <item name="Releases" href="http://sourceforge.net/project/showfiles.php?group_id=30014"/>
+ <item name="Maven" href="http://www.microemu.org/maven.html"/>-->
+ <item name="SVN Access" href="source-repository.html"/>
+ <item name="Browse SVN" href="http://p2play.svn.sourceforge.net/viewvc/p2play/trunk/parent/"/>
+ </item>
+
+ <!--4release-->
+ <!--
+ <item name="Preview 2.0.2" href="http://pyx4j.com/snapshot/microemu/" />
+ -->
+<!-- <item name="Changes and Plans" href="http://www.microemu.org/changes-report.html" />-->
+ </menu>
+
+<!-- <menu name="Live examples">
+ <item name="Applets" href="http://www.microemu.org/demo.html" />
+ <item name="Web Start" href="http://www.microemu.org/microemu-webstart/demo.jnlp" />
+ </menu>-->
+
+ <menu ref="modules" collapse="true" />
+
+ <menu ref="reports" />
+
+ </body>
+
+</project>
\ No newline at end of file
Property changes on: trunk/parent/src/site/site.xml
___________________________________________________________________
Name: svn:mime-type
+ text/plain
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-22 06:58:09
|
Revision: 80
http://p2play.svn.sourceforge.net/p2play/?rev=80&view=rev
Author: tisoft
Date: 2007-08-21 23:58:12 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
added simple test case
Modified Paths:
--------------
trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java
Modified: trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java
===================================================================
--- trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java 2007-08-21 18:19:48 UTC (rev 79)
+++ trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java 2007-08-22 06:58:12 UTC (rev 80)
@@ -15,5 +15,6 @@
assertNull(byteArrayResource.getData());
assertNull(byteArrayResource.getId());
assertEquals(byteArrayResource.getExpiration(),GCPast.INFINITY_EXPIRATION);
+ assertTrue(byteArrayResource.isMutable());
}
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 18:19:51
|
Revision: 79
http://p2play.svn.sourceforge.net/p2play/?rev=79&view=rev
Author: tisoft
Date: 2007-08-21 11:19:48 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
updated pom
Modified Paths:
--------------
trunk/parent/pom.xml
Modified: trunk/parent/pom.xml
===================================================================
--- trunk/parent/pom.xml 2007-08-21 17:58:39 UTC (rev 78)
+++ trunk/parent/pom.xml 2007-08-21 18:19:48 UTC (rev 79)
@@ -23,7 +23,7 @@
<notifiers>
<notifier>
<type>mail</type>
- <address>ma...@ti...</address>
+ <address>tisoft</address>
</notifier>
</notifiers>
</ciManagement>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 17:58:36
|
Revision: 78
http://p2play.svn.sourceforge.net/p2play/?rev=78&view=rev
Author: tisoft
Date: 2007-08-21 10:58:39 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
updated pom
Modified Paths:
--------------
trunk/parent/pom.xml
Modified: trunk/parent/pom.xml
===================================================================
--- trunk/parent/pom.xml 2007-08-21 17:57:33 UTC (rev 77)
+++ trunk/parent/pom.xml 2007-08-21 17:58:39 UTC (rev 78)
@@ -17,6 +17,17 @@
<module>org.p2play.eclipse</module>
</modules>
+ <ciManagement>
+ <system>Continuum</system>
+ <url>http://continuum.tisoft.de</url>
+ <notifiers>
+ <notifier>
+ <type>mail</type>
+ <address>ma...@ti...</address>
+ </notifier>
+ </notifiers>
+ </ciManagement>
+
<licenses>
<license>
<name>GNU Lesser General Public License, version 2.1</name>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 17:57:31
|
Revision: 77
http://p2play.svn.sourceforge.net/p2play/?rev=77&view=rev
Author: tisoft
Date: 2007-08-21 10:57:33 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
added simple test case
Added Paths:
-----------
trunk/parent/p2play/src/test/
trunk/parent/p2play/src/test/java/
trunk/parent/p2play/src/test/java/org/
trunk/parent/p2play/src/test/java/org/p2play/
trunk/parent/p2play/src/test/java/org/p2play/resource/
trunk/parent/p2play/src/test/java/org/p2play/resource/impl/
trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java
Added: trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java
===================================================================
--- trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java (rev 0)
+++ trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java 2007-08-21 17:57:33 UTC (rev 77)
@@ -0,0 +1,19 @@
+package org.p2play.resource.impl;
+
+import static org.junit.Assert.*;
+
+import org.junit.Test;
+
+import rice.p2p.past.gc.GCPast;
+
+public class ByteArrayResourceTest {
+
+ @Test
+ public void testNewByteArrayResource() {
+ ByteArrayResource byteArrayResource=new ByteArrayResource(null, null);
+ assertNotNull(byteArrayResource);
+ assertNull(byteArrayResource.getData());
+ assertNull(byteArrayResource.getId());
+ assertEquals(byteArrayResource.getExpiration(),GCPast.INFINITY_EXPIRATION);
+ }
+}
Property changes on: trunk/parent/p2play/src/test/java/org/p2play/resource/impl/ByteArrayResourceTest.java
___________________________________________________________________
Name: svn:mime-type
+ text/plain
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 17:11:37
|
Revision: 76
http://p2play.svn.sourceforge.net/p2play/?rev=76&view=rev
Author: tisoft
Date: 2007-08-21 10:11:39 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
updated pom
Modified Paths:
--------------
trunk/parent/pom.xml
Modified: trunk/parent/pom.xml
===================================================================
--- trunk/parent/pom.xml 2007-08-21 14:45:43 UTC (rev 75)
+++ trunk/parent/pom.xml 2007-08-21 17:11:39 UTC (rev 76)
@@ -28,10 +28,10 @@
<scm>
<connection>
- scm:svn:http://p2play.svn.sourceforge.net/svnroot/p2play/
+ scm:svn:http://p2play.svn.sourceforge.net/svnroot/p2play/trunk/parent/
</connection>
<developerConnection>
- scm:svn:https://p2play.svn.sourceforge.net/svnroot/p2play/
+ scm:svn:https://p2play.svn.sourceforge.net/svnroot/p2play/trunk/parent/
</developerConnection>
<url>http://p2play.svn.sourceforge.net/viewvc/p2play/</url>
</scm>
@@ -220,19 +220,34 @@
<artifactId>maven-javadoc-plugin</artifactId>
</plugin>
<plugin>
- <artifactId>maven-surefire-plugin</artifactId>
+ <groupId>org.codehaus.mojo</groupId>
+ <artifactId>jxr-maven-plugin</artifactId>
</plugin>
<plugin>
- <artifactId>maven-clover-plugin</artifactId>
+ <artifactId>maven-surefire-report-plugin</artifactId>
</plugin>
<plugin>
<groupId>org.codehaus.mojo</groupId>
+ <artifactId>cobertura-maven-plugin</artifactId>
+ </plugin>
+ <plugin>
+ <groupId>org.codehaus.mojo</groupId>
<artifactId>changelog-maven-plugin</artifactId>
</plugin>
<plugin>
<groupId>org.codehaus.mojo</groupId>
<artifactId>taglist-maven-plugin</artifactId>
</plugin>
+ <plugin>
+ <groupId>org.apache.maven.plugins</groupId>
+ <artifactId>maven-pmd-plugin</artifactId>
+ <configuration>
+ <linkXref>true</linkXref>
+ <sourceEncoding>utf-8</sourceEncoding>
+ <minimumTokens>100</minimumTokens>
+ <targetJdk>1.5</targetJdk>
+ </configuration>
+ </plugin>
</plugins>
</reporting>
@@ -252,6 +267,38 @@
<target>1.5</target>
</configuration>
</plugin>
+ <plugin>
+ <groupId>org.codehaus.mojo</groupId>
+ <artifactId>cobertura-maven-plugin</artifactId>
+ <executions>
+ <execution>
+ <phase>test</phase>
+ <goals>
+ <goal>cobertura</goal>
+ </goals>
+ </execution>
+ </executions>
+ </plugin>
+ <plugin>
+ <groupId>org.apache.maven.plugins</groupId>
+ <artifactId>maven-site-plugin</artifactId>
+ <executions>
+ <execution>
+ <id>site</id>
+ <phase>package</phase>
+ <goals>
+ <goal>site</goal>
+ </goals>
+ </execution>
+ <execution>
+ <id>deploy</id>
+ <phase>deploy</phase>
+ <goals>
+ <goal>deploy</goal>
+ </goals>
+ </execution>
+ </executions>
+ </plugin>
</plugins>
</build>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 14:45:43
|
Revision: 75
http://p2play.svn.sourceforge.net/p2play/?rev=75&view=rev
Author: tisoft
Date: 2007-08-21 07:45:43 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
added information/reports to the poms
Modified Paths:
--------------
trunk/parent/boot/pom.xml
trunk/parent/org.p2play.eclipse/pom.xml
trunk/parent/p2play/pom.xml
trunk/parent/pom.xml
Modified: trunk/parent/boot/pom.xml
===================================================================
--- trunk/parent/boot/pom.xml 2007-08-21 12:12:06 UTC (rev 74)
+++ trunk/parent/boot/pom.xml 2007-08-21 14:45:43 UTC (rev 75)
@@ -7,6 +7,9 @@
<artifactId>boot</artifactId>
<version>0.0.1-SNAPSHOT</version>
+ <name>P2Play Boot</name>
+ <url>http://p2play.org/site/boot</url>
+
<parent>
<groupId>org.p2play</groupId>
<artifactId>parent</artifactId>
Modified: trunk/parent/org.p2play.eclipse/pom.xml
===================================================================
--- trunk/parent/org.p2play.eclipse/pom.xml 2007-08-21 12:12:06 UTC (rev 74)
+++ trunk/parent/org.p2play.eclipse/pom.xml 2007-08-21 14:45:43 UTC (rev 75)
@@ -5,10 +5,12 @@
<modelVersion>4.0.0</modelVersion>
<groupId>org.p2play</groupId>
<artifactId>org.p2play.eclipse</artifactId>
- <name>P2Play Eclipse Enablement</name>
- <version>0.0.1-SNAPSHOT</version>
+ <version>0.0.1-SNAPSHOT</version>
- <parent>
+ <name>P2Play Eclipse Enablement</name>
+ <url>http://p2play.org/site/org.p2play.eclipse</url>
+
+ <parent>
<groupId>org.p2play</groupId>
<artifactId>parent</artifactId>
<version>0.0.1-SNAPSHOT</version>
Modified: trunk/parent/p2play/pom.xml
===================================================================
--- trunk/parent/p2play/pom.xml 2007-08-21 12:12:06 UTC (rev 74)
+++ trunk/parent/p2play/pom.xml 2007-08-21 14:45:43 UTC (rev 75)
@@ -7,7 +7,10 @@
<artifactId>p2play</artifactId>
<version>0.0.1-SNAPSHOT</version>
- <parent>
+ <name>P2Play</name>
+ <url>http://p2play.org/site/p2play</url>
+
+ <parent>
<groupId>org.p2play</groupId>
<artifactId>parent</artifactId>
<version>0.0.1-SNAPSHOT</version>
Modified: trunk/parent/pom.xml
===================================================================
--- trunk/parent/pom.xml 2007-08-21 12:12:06 UTC (rev 74)
+++ trunk/parent/pom.xml 2007-08-21 14:45:43 UTC (rev 75)
@@ -7,22 +7,60 @@
<artifactId>parent</artifactId>
<version>0.0.1-SNAPSHOT</version>
<packaging>pom</packaging>
+
+ <name>P2Play Super POM</name>
+ <url>http://p2play.org/site</url>
+
<modules>
<module>boot</module>
<module>p2play</module>
<module>org.p2play.eclipse</module>
</modules>
-
-
+
+ <licenses>
+ <license>
+ <name>GNU Lesser General Public License, version 2.1</name>
+ <url>
+ http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt
+ </url>
+ </license>
+ </licenses>
+
+ <scm>
+ <connection>
+ scm:svn:http://p2play.svn.sourceforge.net/svnroot/p2play/
+ </connection>
+ <developerConnection>
+ scm:svn:https://p2play.svn.sourceforge.net/svnroot/p2play/
+ </developerConnection>
+ <url>http://p2play.svn.sourceforge.net/viewvc/p2play/</url>
+ </scm>
+
+ <mailingLists>
+ <mailingList>
+ <name>P2Play commit</name>
+ <subscribe>
+ https://lists.sourceforge.net/lists/listinfo/p2play-commit
+ </subscribe>
+ <unsubscribe>
+ https://lists.sourceforge.net/lists/listinfo/p2play-commit
+ </unsubscribe>
+ <post>p2p...@li...</post>
+ <archive>
+ http://sourceforge.net/mailarchive/forum.php?forum_name=p2play-commit
+ </archive>
+ </mailingList>
+ </mailingLists>
+
<repositories>
<repository>
<id>maven.tisoft.de</id>
<url>http://maven.tisoft.de/repository</url>
</repository>
</repositories>
-
+
<pluginRepositories>
- <pluginRepository>
+ <pluginRepository>
<id>maven.tisoft.de</id>
<url>http://maven.tisoft.de/repository</url>
<releases>
@@ -33,20 +71,177 @@
</snapshots>
</pluginRepository>
</pluginRepositories>
-
+
<distributionManagement>
<repository>
<id>maven.tisoft.de</id>
<url>ftp://maven.tisoft.de/repository</url>
</repository>
+ <site>
+ <id>p2play.org</id>
+ <url>ftp://p2play.org/site</url>
+ </site>
</distributionManagement>
-
+
+ <developers>
+ <developer>
+ <id>tisoft</id>
+ <name>Markus Heberling</name>
+ <email>ma...@ti...</email>
+ <roles>
+ <role>Project Manager</role>
+ <role>Architect</role>
+ <role>Developer</role>
+ </roles>
+ <organization>tisoft media</organization>
+ <organizationUrl>http://tisoft.de</organizationUrl>
+ <timezone>+2</timezone>
+ </developer>
+ </developers>
+
+ <contributors>
+ <contributor>
+ <name>Tobias Berghoff</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Andre Braun</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Kai Brinksmeier</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Marco Gießman</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Jürgen Hölker</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Kamil Kopel</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Marko Kowalczyk</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Johannes Lintner</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Ingo Niehaus</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Markus Podlacha</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Dilek Say</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Andre Schmitz</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Metaxia Vavritsa</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ <contributor>
+ <name>Raphael Weber</name>
+ <organization>University of Paderborn</organization>
+ <organizationUrl>http://upb.de</organizationUrl>
+ <roles>
+ <role>Developer</role>
+ </roles>
+ </contributor>
+ </contributors>
+
+ <reporting>
+ <plugins>
+ <plugin>
+ <artifactId>maven-javadoc-plugin</artifactId>
+ </plugin>
+ <plugin>
+ <artifactId>maven-surefire-plugin</artifactId>
+ </plugin>
+ <plugin>
+ <artifactId>maven-clover-plugin</artifactId>
+ </plugin>
+ <plugin>
+ <groupId>org.codehaus.mojo</groupId>
+ <artifactId>changelog-maven-plugin</artifactId>
+ </plugin>
+ <plugin>
+ <groupId>org.codehaus.mojo</groupId>
+ <artifactId>taglist-maven-plugin</artifactId>
+ </plugin>
+ </plugins>
+ </reporting>
+
<build>
<extensions>
<extension>
<groupId>org.apache.maven.wagon</groupId>
<artifactId>wagon-ftp</artifactId>
- <version>1.0-beta-2</version>
+ <version>2.0-SNAPSHOT</version>
</extension>
</extensions>
<plugins>
@@ -59,5 +254,5 @@
</plugin>
</plugins>
</build>
-
+
</project>
\ No newline at end of file
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 12:12:10
|
Revision: 74
http://p2play.svn.sourceforge.net/p2play/?rev=74&view=rev
Author: tisoft
Date: 2007-08-21 05:12:06 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
added ignores
Property Changed:
----------------
trunk/parent/
trunk/parent/boot/
trunk/parent/org.p2play.eclipse/
trunk/parent/p2play/
Property changes on: trunk/parent
___________________________________________________________________
Name: svn:ignore
+ .classpath
.project
target
Property changes on: trunk/parent/boot
___________________________________________________________________
Name: svn:ignore
- bin
target
+ bin
target
.project
.classpath
Property changes on: trunk/parent/org.p2play.eclipse
___________________________________________________________________
Name: svn:ignore
+ .classpath
target
lib
META-INF
.project
.settings
Property changes on: trunk/parent/p2play
___________________________________________________________________
Name: svn:ignore
- bin
target
+ bin
target
.project
.classpath
.settings
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 12:09:44
|
Revision: 73
http://p2play.svn.sourceforge.net/p2play/?rev=73&view=rev
Author: tisoft
Date: 2007-08-21 05:09:47 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
updated for new freepastry snapshot
Modified Paths:
--------------
trunk/parent/p2play/src/main/java/org/p2play/scripting/pnuts/api/statistic/StatisticAPI.java
Modified: trunk/parent/p2play/src/main/java/org/p2play/scripting/pnuts/api/statistic/StatisticAPI.java
===================================================================
--- trunk/parent/p2play/pom.xml 2007-08-21 12:07:49 UTC (rev 71)
+++ trunk/parent/p2play/pom.xml 2007-08-21 12:09:09 UTC (rev 72)
@@ -7,27 +7,15 @@
<artifactId>p2play</artifactId>
<version>0.0.1-SNAPSHOT</version>
- <repositories>
- <repository>
- <id>maven.tisoft.de</id>
- <url>http://maven.tisoft.de/repository</url>
- </repository>
- </repositories>
-
- <distributionManagement>
- <repository>
- <id>maven.tisoft.de</id>
- <url>ftp://maven.tisoft.de/repository</url>
- </repository>
- </distributionManagement>
+ <parent>
+ <groupId>org.p2play</groupId>
+ <artifactId>parent</artifactId>
+ <version>0.0.1-SNAPSHOT</version>
+ </parent>
+
+ <packaging>jar</packaging>
<build>
- <extensions>
- <extension>
- <groupId>org.apache.maven.wagon</groupId>
- <artifactId>wagon-ftp</artifactId>
- </extension>
- </extensions>
<plugins>
<plugin>
<artifactId>maven-compiler-plugin</artifactId>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 12:07:46
|
Revision: 71
http://p2play.svn.sourceforge.net/p2play/?rev=71&view=rev
Author: tisoft
Date: 2007-08-21 05:07:49 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
updated pom
Modified Paths:
--------------
trunk/parent/boot/pom.xml
Modified: trunk/parent/boot/pom.xml
===================================================================
--- trunk/parent/boot/pom.xml 2007-08-21 12:06:13 UTC (rev 70)
+++ trunk/parent/boot/pom.xml 2007-08-21 12:07:49 UTC (rev 71)
@@ -1,33 +1,19 @@
<?xml version="1.0" encoding="UTF-8"?>
-<project>
+<project xmlns="http://maven.apache.org/POM/4.0.0"
+ xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+ xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
<modelVersion>4.0.0</modelVersion>
<groupId>org.p2play</groupId>
<artifactId>boot</artifactId>
- <version>0.0.1-SNAPSHOT</version>
- <distributionManagement>
- <repository>
- <id>maven.tisoft.de</id>
- <url>ftp://maven.tisoft.de/repository</url>
- </repository>
- </distributionManagement>
+ <version>0.0.1-SNAPSHOT</version>
+
+ <parent>
+ <groupId>org.p2play</groupId>
+ <artifactId>parent</artifactId>
+ <version>0.0.1-SNAPSHOT</version>
+ </parent>
- <build>
- <extensions>
- <extension>
- <groupId>org.apache.maven.wagon</groupId>
- <artifactId>wagon-ftp</artifactId>
- </extension>
- </extensions>
- <plugins>
- <plugin>
- <artifactId>maven-compiler-plugin</artifactId>
- <configuration>
- <source>1.5</source>
- <target>1.5</target>
- </configuration>
- </plugin>
- </plugins>
- </build>
+ <packaging>jar</packaging>
<dependencies>
<dependency>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 12:06:18
|
Revision: 70
http://p2play.svn.sourceforge.net/p2play/?rev=70&view=rev
Author: tisoft
Date: 2007-08-21 05:06:13 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
added eclipse plugin project
updated parent pom
Modified Paths:
--------------
trunk/parent/pom.xml
Added Paths:
-----------
trunk/parent/org.p2play.eclipse/
trunk/parent/org.p2play.eclipse/pom.xml
Added: trunk/parent/org.p2play.eclipse/pom.xml
===================================================================
--- trunk/parent/org.p2play.eclipse/pom.xml (rev 0)
+++ trunk/parent/org.p2play.eclipse/pom.xml 2007-08-21 12:06:13 UTC (rev 70)
@@ -0,0 +1,43 @@
+<project xmlns="http://maven.apache.org/POM/4.0.0"
+ xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+ xsi:schemaLocation="http://maven.apache.org/POM/4.0.0
+ http://maven.apache.org/maven-v4_0_0.xsd">
+ <modelVersion>4.0.0</modelVersion>
+ <groupId>org.p2play</groupId>
+ <artifactId>org.p2play.eclipse</artifactId>
+ <name>P2Play Eclipse Enablement</name>
+ <version>0.0.1-SNAPSHOT</version>
+
+ <parent>
+ <groupId>org.p2play</groupId>
+ <artifactId>parent</artifactId>
+ <version>0.0.1-SNAPSHOT</version>
+ </parent>
+
+ <packaging>pom</packaging>
+
+ <build>
+ <plugins>
+ <plugin>
+ <groupId>org.apache.maven.plugins</groupId>
+ <artifactId>maven-psteclipse-plugin</artifactId>
+ <executions>
+ <execution>
+ <phase>package</phase>
+ <goals>
+ <goal>eclipse-plugin</goal>
+ </goals>
+ </execution>
+ </executions>
+ </plugin>
+ </plugins>
+ </build>
+
+ <dependencies>
+ <dependency>
+ <groupId>org.p2play</groupId>
+ <artifactId>p2play</artifactId>
+ <version>0.0.1-SNAPSHOT</version>
+ </dependency>
+ </dependencies>
+</project>
\ No newline at end of file
Property changes on: trunk/parent/org.p2play.eclipse/pom.xml
___________________________________________________________________
Name: svn:mime-type
+ text/plain
Modified: trunk/parent/pom.xml
===================================================================
--- trunk/parent/pom.xml 2007-08-21 09:28:34 UTC (rev 69)
+++ trunk/parent/pom.xml 2007-08-21 12:06:13 UTC (rev 70)
@@ -1,8 +1,63 @@
<?xml version="1.0" encoding="UTF-8"?>
-<project>
+<project xmlns="http://maven.apache.org/POM/4.0.0"
+ xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+ xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
<modelVersion>4.0.0</modelVersion>
<groupId>org.p2play</groupId>
<artifactId>parent</artifactId>
<version>0.0.1-SNAPSHOT</version>
<packaging>pom</packaging>
+ <modules>
+ <module>boot</module>
+ <module>p2play</module>
+ <module>org.p2play.eclipse</module>
+ </modules>
+
+
+ <repositories>
+ <repository>
+ <id>maven.tisoft.de</id>
+ <url>http://maven.tisoft.de/repository</url>
+ </repository>
+ </repositories>
+
+ <pluginRepositories>
+ <pluginRepository>
+ <id>maven.tisoft.de</id>
+ <url>http://maven.tisoft.de/repository</url>
+ <releases>
+ <enabled>true</enabled>
+ </releases>
+ <snapshots>
+ <enabled>true</enabled>
+ </snapshots>
+ </pluginRepository>
+ </pluginRepositories>
+
+ <distributionManagement>
+ <repository>
+ <id>maven.tisoft.de</id>
+ <url>ftp://maven.tisoft.de/repository</url>
+ </repository>
+ </distributionManagement>
+
+ <build>
+ <extensions>
+ <extension>
+ <groupId>org.apache.maven.wagon</groupId>
+ <artifactId>wagon-ftp</artifactId>
+ <version>1.0-beta-2</version>
+ </extension>
+ </extensions>
+ <plugins>
+ <plugin>
+ <artifactId>maven-compiler-plugin</artifactId>
+ <configuration>
+ <source>1.5</source>
+ <target>1.5</target>
+ </configuration>
+ </plugin>
+ </plugins>
+ </build>
+
</project>
\ No newline at end of file
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 09:28:31
|
Revision: 69
http://p2play.svn.sourceforge.net/p2play/?rev=69&view=rev
Author: tisoft
Date: 2007-08-21 02:28:34 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
added pom for parent
Added Paths:
-----------
trunk/parent/pom.xml
Added: trunk/parent/pom.xml
===================================================================
--- trunk/parent/pom.xml (rev 0)
+++ trunk/parent/pom.xml 2007-08-21 09:28:34 UTC (rev 69)
@@ -0,0 +1,8 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<project>
+ <modelVersion>4.0.0</modelVersion>
+ <groupId>org.p2play</groupId>
+ <artifactId>parent</artifactId>
+ <version>0.0.1-SNAPSHOT</version>
+ <packaging>pom</packaging>
+</project>
\ No newline at end of file
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 09:24:46
|
Revision: 68
http://p2play.svn.sourceforge.net/p2play/?rev=68&view=rev
Author: tisoft
Date: 2007-08-21 02:24:50 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
removed eclipse stuff
Removed Paths:
-------------
trunk/parent/boot/.classpath
trunk/parent/boot/.project
trunk/parent/boot/.settings/
trunk/parent/p2play/.classpath
trunk/parent/p2play/.project
trunk/parent/p2play/.settings/
Deleted: trunk/parent/boot/.classpath
===================================================================
--- trunk/parent/boot/.classpath 2007-08-21 09:23:48 UTC (rev 67)
+++ trunk/parent/boot/.classpath 2007-08-21 09:24:50 UTC (rev 68)
@@ -1,8 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<classpath>
- <classpathentry kind="src" path="src/main/java"/>
- <classpathentry excluding="**" kind="src" output="src/main/resources" path="src/main/resources"/>
- <classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
- <classpathentry kind="con" path="org.maven.ide.eclipse.MAVEN2_CLASSPATH_CONTAINER"/>
- <classpathentry kind="output" path="target/classes"/>
-</classpath>
Deleted: trunk/parent/boot/.project
===================================================================
--- trunk/parent/boot/.project 2007-08-21 09:23:48 UTC (rev 67)
+++ trunk/parent/boot/.project 2007-08-21 09:24:50 UTC (rev 68)
@@ -1,36 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<projectDescription>
- <name>P2PlayBoot</name>
- <comment></comment>
- <projects>
- </projects>
- <buildSpec>
- <buildCommand>
- <name>org.eclipse.wst.common.project.facet.core.builder</name>
- <arguments>
- </arguments>
- </buildCommand>
- <buildCommand>
- <name>org.eclipse.jdt.core.javabuilder</name>
- <arguments>
- </arguments>
- </buildCommand>
- <buildCommand>
- <name>org.eclipse.wst.validation.validationbuilder</name>
- <arguments>
- </arguments>
- </buildCommand>
- <buildCommand>
- <name>org.maven.ide.eclipse.maven2Builder</name>
- <arguments>
- </arguments>
- </buildCommand>
- </buildSpec>
- <natures>
- <nature>org.eclipse.jdt.core.javanature</nature>
- <nature>org.maven.ide.eclipse.maven2Nature</nature>
- <nature>org.eclipse.wst.common.project.facet.core.nature</nature>
- <nature>org.eclipse.wst.common.modulecore.ModuleCoreNature</nature>
- <nature>org.eclipse.jem.workbench.JavaEMFNature</nature>
- </natures>
-</projectDescription>
Deleted: trunk/parent/p2play/.classpath
===================================================================
--- trunk/parent/p2play/.classpath 2007-08-21 09:23:48 UTC (rev 67)
+++ trunk/parent/p2play/.classpath 2007-08-21 09:24:50 UTC (rev 68)
@@ -1,8 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<classpath>
- <classpathentry kind="src" path="src/main/java"/>
- <classpathentry kind="src" path="src/test/java"/>
- <classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
- <classpathentry exported="true" kind="con" path="org.maven.ide.eclipse.MAVEN2_CLASSPATH_CONTAINER"/>
- <classpathentry kind="output" path="target/classes"/>
-</classpath>
Deleted: trunk/parent/p2play/.project
===================================================================
--- trunk/parent/p2play/.project 2007-08-21 09:23:48 UTC (rev 67)
+++ trunk/parent/p2play/.project 2007-08-21 09:24:50 UTC (rev 68)
@@ -1,36 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<projectDescription>
- <name>P2Play</name>
- <comment></comment>
- <projects>
- </projects>
- <buildSpec>
- <buildCommand>
- <name>org.eclipse.wst.common.project.facet.core.builder</name>
- <arguments>
- </arguments>
- </buildCommand>
- <buildCommand>
- <name>org.eclipse.jdt.core.javabuilder</name>
- <arguments>
- </arguments>
- </buildCommand>
- <buildCommand>
- <name>org.eclipse.wst.validation.validationbuilder</name>
- <arguments>
- </arguments>
- </buildCommand>
- <buildCommand>
- <name>org.maven.ide.eclipse.maven2Builder</name>
- <arguments>
- </arguments>
- </buildCommand>
- </buildSpec>
- <natures>
- <nature>org.eclipse.jdt.core.javanature</nature>
- <nature>org.maven.ide.eclipse.maven2Nature</nature>
- <nature>org.eclipse.wst.common.project.facet.core.nature</nature>
- <nature>org.eclipse.wst.common.modulecore.ModuleCoreNature</nature>
- <nature>org.eclipse.jem.workbench.JavaEMFNature</nature>
- </natures>
-</projectDescription>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 09:23:46
|
Revision: 67
http://p2play.svn.sourceforge.net/p2play/?rev=67&view=rev
Author: tisoft
Date: 2007-08-21 02:23:48 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
Added Paths:
-----------
trunk/parent/p2play/
Removed Paths:
-------------
trunk/parent/P2Play/
Copied: trunk/parent/p2play (from rev 66, trunk/parent/P2Play)
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 09:23:14
|
Revision: 66
http://p2play.svn.sourceforge.net/p2play/?rev=66&view=rev
Author: tisoft
Date: 2007-08-21 02:23:17 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
Added Paths:
-----------
trunk/parent/boot/
Removed Paths:
-------------
trunk/parent/P2PlayBoot/
Copied: trunk/parent/boot (from rev 65, trunk/parent/P2PlayBoot)
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 09:22:47
|
Revision: 65
http://p2play.svn.sourceforge.net/p2play/?rev=65&view=rev
Author: tisoft
Date: 2007-08-21 02:22:50 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
moved P2Play and P2PlayBoot into parent
Added Paths:
-----------
trunk/parent/P2Play/
Removed Paths:
-------------
trunk/P2Play/
Copied: trunk/parent/P2Play (from rev 64, trunk/P2Play)
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 09:22:35
|
Revision: 64
http://p2play.svn.sourceforge.net/p2play/?rev=64&view=rev
Author: tisoft
Date: 2007-08-21 02:22:38 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
moved P2Play and P2PlayBoot into parent
Added Paths:
-----------
trunk/parent/P2PlayBoot/
Removed Paths:
-------------
trunk/P2PlayBoot/
Copied: trunk/parent/P2PlayBoot (from rev 63, trunk/P2PlayBoot)
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 09:21:41
|
Revision: 63
http://p2play.svn.sourceforge.net/p2play/?rev=63&view=rev
Author: tisoft
Date: 2007-08-21 02:21:45 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
added patent project
Added Paths:
-----------
trunk/parent/
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 09:19:45
|
Revision: 62
http://p2play.svn.sourceforge.net/p2play/?rev=62&view=rev
Author: tisoft
Date: 2007-08-21 02:19:39 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
updated to pnuts 1.2
chenged artifactIds
Modified Paths:
--------------
trunk/P2Play/pom.xml
trunk/P2PlayBoot/pom.xml
Modified: trunk/P2Play/pom.xml
===================================================================
--- trunk/P2Play/pom.xml 2007-07-04 08:17:38 UTC (rev 61)
+++ trunk/P2Play/pom.xml 2007-08-21 09:19:39 UTC (rev 62)
@@ -4,7 +4,7 @@
xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
<modelVersion>4.0.0</modelVersion>
<groupId>org.p2play</groupId>
- <artifactId>P2Play</artifactId>
+ <artifactId>p2play</artifactId>
<version>0.0.1-SNAPSHOT</version>
<repositories>
@@ -48,7 +48,7 @@
<dependency>
<groupId>pnuts</groupId>
<artifactId>pnuts</artifactId>
- <version>1.2-BETA</version>
+ <version>1.2</version>
</dependency>
<dependency>
<groupId>jdom</groupId>
@@ -57,7 +57,7 @@
</dependency>
<dependency>
<groupId>org.p2play</groupId>
- <artifactId>P2PlayBoot</artifactId>
+ <artifactId>boot</artifactId>
<version>0.0.1-SNAPSHOT</version>
</dependency>
<dependency>
Modified: trunk/P2PlayBoot/pom.xml
===================================================================
--- trunk/P2PlayBoot/pom.xml 2007-07-04 08:17:38 UTC (rev 61)
+++ trunk/P2PlayBoot/pom.xml 2007-08-21 09:19:39 UTC (rev 62)
@@ -2,7 +2,7 @@
<project>
<modelVersion>4.0.0</modelVersion>
<groupId>org.p2play</groupId>
- <artifactId>P2PlayBoot</artifactId>
+ <artifactId>boot</artifactId>
<version>0.0.1-SNAPSHOT</version>
<distributionManagement>
<repository>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-07-04 08:17:37
|
Revision: 61
http://p2play.svn.sourceforge.net/p2play/?rev=61&view=rev
Author: tisoft
Date: 2007-07-04 01:17:38 -0700 (Wed, 04 Jul 2007)
Log Message:
-----------
moved to trunk
Added Paths:
-----------
trunk/P2PlayServiceServer/
Removed Paths:
-------------
P2PlayServiceServer/
Copied: trunk/P2PlayServiceServer (from rev 60, P2PlayServiceServer)
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-07-04 08:17:28
|
Revision: 60
http://p2play.svn.sourceforge.net/p2play/?rev=60&view=rev
Author: tisoft
Date: 2007-07-04 01:17:30 -0700 (Wed, 04 Jul 2007)
Log Message:
-----------
moved to trunk
Added Paths:
-----------
trunk/P2PlayService/
Removed Paths:
-------------
P2PlayService/
Copied: trunk/P2PlayService (from rev 59, P2PlayService)
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-07-04 08:15:32
|
Revision: 59
http://p2play.svn.sourceforge.net/p2play/?rev=59&view=rev
Author: tisoft
Date: 2007-07-04 01:15:31 -0700 (Wed, 04 Jul 2007)
Log Message:
-----------
added javolution 5
added tisoft repository
Modified Paths:
--------------
trunk/P2Play/pom.xml
Modified: trunk/P2Play/pom.xml
===================================================================
--- trunk/P2Play/pom.xml 2007-07-04 08:14:39 UTC (rev 58)
+++ trunk/P2Play/pom.xml 2007-07-04 08:15:31 UTC (rev 59)
@@ -5,7 +5,15 @@
<modelVersion>4.0.0</modelVersion>
<groupId>org.p2play</groupId>
<artifactId>P2Play</artifactId>
- <version>0.0.1-SNAPSHOT</version>
+ <version>0.0.1-SNAPSHOT</version>
+
+ <repositories>
+ <repository>
+ <id>maven.tisoft.de</id>
+ <url>http://maven.tisoft.de/repository</url>
+ </repository>
+ </repositories>
+
<distributionManagement>
<repository>
<id>maven.tisoft.de</id>
@@ -33,9 +41,9 @@
<dependencies>
<dependency>
- <groupId>javolution</groupId>
+ <groupId>de.tisoft.maven.javolution</groupId>
<artifactId>javolution</artifactId>
- <version>4.2.6</version>
+ <version>5.0.3</version>
</dependency>
<dependency>
<groupId>pnuts</groupId>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-07-04 08:14:37
|
Revision: 58
http://p2play.svn.sourceforge.net/p2play/?rev=58&view=rev
Author: tisoft
Date: 2007-07-04 01:14:39 -0700 (Wed, 04 Jul 2007)
Log Message:
-----------
added maven2 output folder
Modified Paths:
--------------
P2PlayLegacy/.classpath
Property Changed:
----------------
P2PlayLegacy/
Property changes on: P2PlayLegacy
___________________________________________________________________
Name: svn:ignore
- bin
+ bin
target
Modified: P2PlayLegacy/.classpath
===================================================================
--- P2PlayLegacy/.classpath 2007-07-04 07:34:06 UTC (rev 57)
+++ P2PlayLegacy/.classpath 2007-07-04 08:14:39 UTC (rev 58)
@@ -3,5 +3,5 @@
<classpathentry kind="src" path="src"/>
<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
<classpathentry kind="con" path="org.maven.ide.eclipse.MAVEN2_CLASSPATH_CONTAINER"/>
- <classpathentry kind="output" path="bin"/>
+ <classpathentry kind="output" path="target/classes"/>
</classpath>
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-07-04 07:34:06
|
Revision: 57
http://p2play.svn.sourceforge.net/p2play/?rev=57&view=rev
Author: tisoft
Date: 2007-07-04 00:34:06 -0700 (Wed, 04 Jul 2007)
Log Message:
-----------
fixed broken commit
Modified Paths:
--------------
trunk/P2PlayBoot/src/main/java/org/p2play/boot/discovery/LocalDiscovery.java
trunk/P2PlayBoot/src/main/java/org/p2play/boot/discovery/ServiceInfo.java
trunk/P2PlayBoot/src/main/java/org/p2play/boot/discovery/ServiceListener.java
Modified: trunk/P2PlayBoot/src/main/java/org/p2play/boot/discovery/LocalDiscovery.java
===================================================================
--- trunk/P2PlayBoot/src/main/java/org/p2play/boot/discovery/LocalDiscovery.java 2007-07-02 20:17:13 UTC (rev 56)
+++ trunk/P2PlayBoot/src/main/java/org/p2play/boot/discovery/LocalDiscovery.java 2007-07-04 07:34:06 UTC (rev 57)
@@ -1 +1,42 @@
-nking.gad.de/banking/banking;jsessionid=4447ED60BA4FB2B170C60AA08D6547A6.node4?bankidTimeout=4453&viewName=HoleUmsatzDetails&action=HoleAlleUmsaetze&applId=ib_banking&frame=content&timeout=4453[203602139.1\xD4 |
--- trunk/parent/p2play/src/main/java/org/p2play/scripting/pnuts/api/statistic/StatisticAPI.java 2007-08-21 12:09:09 UTC (rev 72)
+++ trunk/parent/p2play/src/main/java/org/p2play/scripting/pnuts/api/statistic/StatisticAPI.java 2007-08-21 12:09:47 UTC (rev 73)
@@ -28,16 +28,16 @@
import pnuts.lang.PnutsFunction;
import rice.p2p.commonapi.Node;
import rice.pastry.NetworkListener;
-import rice.pastry.dist.DistPastryNode;
+import rice.pastry.PastryNode;
public class StatisticAPI implements NetworkListener, ScriptAPI{
private Statistic statistic;
public StatisticAPI(Node node) {
statistic=new Statistic();
- //only add if we have a DistPastryNode
- if(node instanceof DistPastryNode)
- ((DistPastryNode) node).addNetworkListener(this);
+ //only add if we have a PastryNode
+ if(node instanceof PastryNode)
+ ((PastryNode) node).addNetworkListener(this);
}
public void registerAPI(PackageHandler packageHandler) {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
|
From: <ti...@us...> - 2007-08-21 12:09:07
|
Revision: 72
http://p2play.svn.sourceforge.net/p2play/?rev=72&view=rev
Author: tisoft
Date: 2007-08-21 05:09:09 -0700 (Tue, 21 Aug 2007)
Log Message:
-----------
updated pom
Modified Paths:
--------------
trunk/parent/p2play/pom.xml
Modified: trunk/parent/p2play/pom.xml
===================================================================